package com.ruoyi.project.hit.controller;

import com.alibaba.excel.EasyExcel;
import com.alibaba.excel.support.ExcelTypeEnum;
import com.alibaba.fastjson.JSON;
import com.ruoyi.common.exception.CustomException;
import com.ruoyi.common.utils.ServletUtils;
import com.ruoyi.common.utils.http.HttpHelper;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.framework.aspectj.lang.annotation.Log;
import com.ruoyi.framework.aspectj.lang.enums.BusinessType;
import com.ruoyi.framework.security.LoginUser;
import com.ruoyi.framework.web.controller.BaseController;
import com.ruoyi.framework.web.domain.AjaxResult;
import com.ruoyi.framework.web.page.TableDataInfo;
import com.ruoyi.project.hit.controller.vo.ExcelCardProductVo;
import com.ruoyi.project.hit.controller.vo.ListCardProductVo;
import com.ruoyi.project.hit.controller.vo.ListCardUserVo;
import com.ruoyi.project.hit.domain.CardProduct;
import com.ruoyi.project.hit.service.CardProductService;
import com.ruoyi.project.system.domain.SysUser;
import io.swagger.annotations.Api;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.math.BigDecimal;
import java.util.*;

@RestController
@RequestMapping("/hit/product")
@Api(tags = "EasyExcel")
public class CardProductController extends BaseController {
    @Autowired
    private CardProductService cardProductService;


    /**
     * 获取奖品列表
     */
    @GetMapping("/list")
    public TableDataInfo list(ListCardProductVo listCardProductVo)
    {
        startPage();
        List<CardProduct> list = cardProductService.selectCardProductList(listCardProductVo);
        return getDataTable(list);
    }

    /**
     * 根据id查询奖品
     * @param id
     * @return
     */
    @GetMapping("/{id}")
    public AjaxResult getProductById(@PathVariable Integer id)
    {
        return AjaxResult.success(cardProductService.getProductById(id));
    }



    /**
     * 修改奖品列表
     */
    @PutMapping
    public AjaxResult updateProduct(@RequestBody CardProduct cardProduct)
    {
        cardProductService.updateProduct(cardProduct);
        return AjaxResult.success("修改成功");
    }

    /**
     * 删除奖品
     */
    @DeleteMapping("/{id}")
    public AjaxResult deleteProduct(@PathVariable Integer id)
    {
        return toAjax(cardProductService.deleteProduct(id));
    }

    /**
     * 新增奖品
     * @param cardProduct
     * @return
     */
    @PostMapping
    public AjaxResult addProduct(@RequestBody CardProduct cardProduct)
    {
        return toAjax(cardProductService.addProduct(cardProduct));
    }

    /**
     * 奖品列表显示
     * @return 奖品列表
     */
    @GetMapping("/select")
    public AjaxResult select()
    {
        List<Map<String,Object>> list=cardProductService.select();
        return AjaxResult.success("查询成功",list);
    }

    /**
     * 奖品列表导入接口
     * @param file
     * @return
     * @throws Exception
     */
    @Log(title = "奖品管理", businessType = BusinessType.IMPORT)
//    @PreAuthorize("@ss.hasPermi('system:user:import')")
    @PostMapping("/uploadExcel")
    public AjaxResult importData(@RequestPart(value = "myExcel") MultipartFile file) throws Exception
    {
        try {
            List<CardProduct> cardProducts = EasyExcel.read(file.getInputStream())
                    .head(CardProduct.class)
                    .sheet()
                    .doReadSync();
            if(cardProducts.size()==0){
                throw new CustomException("导入失败，excel表空数据");
            }

            boolean b = cardProductService.saveBatch(cardProducts);
            if(b){
                return AjaxResult.success(null);
            }else {
                throw new CustomException("导入失败，存在错误数据");
            }
        } catch (IOException e) {
            return AjaxResult.error();
        }

    }


    /**
     *excel表导出
     * @param ids
     */
    @PostMapping("/export")
    public AjaxResult export(@RequestBody List<Integer> ids,HttpServletResponse response){
        if(ids.isEmpty()){
            throw new CustomException("未选择要导出的数据");
        }
//        List<CardProduct> cardProducts = cardProductService.listByIds(ids);
//        String s1=exportUserExcel(cardProducts,response);
//        response.reset();
//        AjaxResult result =AjaxResult.success(s1);
//        String json = JSON.toJSONString(result);
//        ServletUtils.renderString(response, json);
        String s1="";
        try {
            List<CardProduct> cardProducts = cardProductService.listByIds(ids);
            s1=exportUserExcel(cardProducts,response);
        } catch (Exception e) {
            e.printStackTrace();
            response.reset();
            AjaxResult result = AjaxResult.error(e.getMessage());
            String json = JSON.toJSONString(result);
            HttpHelper.renderString(response, json);
        }
        return null;
    }



    public String exportUserExcel(List<CardProduct> cardProducts,HttpServletResponse response)throws Exception {
        String s1="";

            s1 ="product_" +this.setExcelResponseProp(response, "奖品列表");
            EasyExcel.write(response.getOutputStream())
                    .head(CardProduct.class)
                    .excelType(ExcelTypeEnum.XLSX)
                    .sheet("奖品列表")
                    .doWrite(cardProducts);;
        return s1;
    }

    /**
     * 设置响应结果
     *
     * @param response    响应结果对象
     * @param rawFileName 文件名
     *@throws UnsupportedEncodingException 不支持编码异常
     */
    private String setExcelResponseProp(HttpServletResponse response, String rawFileName) throws UnsupportedEncodingException {
        response.setContentType("application/vnd.openxmlformats-officedocument.spreadsheetml.sheet");
        response.setCharacterEncoding("utf-8");
        String fileName = new Date().toString();

        response.setHeader("Content-disposition", "attachment;filename*=utf-8''" + fileName + ".xlsx");
        return fileName;
    }

}
