package com.ruoyi.project.hit.controller;

import com.ruoyi.common.constant.UserConstants;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.framework.aspectj.lang.annotation.Log;
import com.ruoyi.framework.aspectj.lang.enums.BusinessType;
import com.ruoyi.framework.web.controller.BaseController;
import com.ruoyi.framework.web.domain.AjaxResult;
import com.ruoyi.framework.web.page.TableDataInfo;
import com.ruoyi.project.hit.domain.SystemDict;
import com.ruoyi.project.hit.service.SystemDictService;
import com.ruoyi.project.system.domain.SysPost;
import org.springframework.beans.factory.annotation.Autowired;

import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@RestController
@RequestMapping("/hit/dict")
public class SystemDictController extends BaseController {
    @Autowired
    private SystemDictService systemDictService;
    /**
     * 获取會員等級列表
     */
   // @PreAuthorize("@ss.hasPermi('system:dict:list')")
    @GetMapping("/list")
    public TableDataInfo list(SystemDict dict)
    {
        startPage();
        List<SystemDict> list = systemDictService.selectSystemDictList(dict);
        return getDataTable(list);
    }


    /**
     * 新增会员等级
     */
//    @PreAuthorize("@ss.hasPermi('system:dict:add')")
    @Log(title = "会员等级管理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@Validated @RequestBody SystemDict dict)
    {
        if (UserConstants.NOT_UNIQUE.equals(systemDictService.checkDictValueUnique(dict)))
        {
            return AjaxResult.error("新增会员等级'" + dict.getDictValue() + "'失败，会员等级名称已存在");
        }
        else if (UserConstants.NOT_UNIQUE.equals(systemDictService.checkDictKeyUnique(dict)))
        {
            return AjaxResult.error("新增会员等级'" + dict.getDictKey() + "'失败，会员等级代号已存在");
        }
//        dict.setCreateBy(SecurityUtils.getUsername());
        return toAjax(systemDictService.insertDict(dict));
    }

    /**
     * 删除会员等级
     */
//    @PreAuthorize("@ss.hasPermi('system:post:remove')")
    @Log(title = "会员等级管理", businessType = BusinessType.DELETE)
    @DeleteMapping("/{id}")
    public AjaxResult remove(@PathVariable Integer id)
    {
        System.out.println("111");
        return toAjax(systemDictService.deleteDictById(id));
    }

    /**
     * 根据会员等级编号获取详细信息
     */
//    @PreAuthorize("@ss.hasPermi('system:post:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable Long id)
    {
        return AjaxResult.success(systemDictService.selectDictById(id));
    }


    /**
     * 修改会员等级
     */
//    @PreAuthorize("@ss.hasPermi('system:post:edit')")
    @Log(title = "会员等级管理", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@Validated @RequestBody SystemDict dict)
    {
        if (UserConstants.NOT_UNIQUE.equals(systemDictService.checkDictValueUnique(dict)))
        {
            return AjaxResult.error("修改会员等级'" + dict.getDictValue() + "'失败，会员等级名称已存在");
        }
        else if (UserConstants.NOT_UNIQUE.equals(systemDictService.checkDictKeyUnique(dict)))
        {
            return AjaxResult.error("修改会员等级'" + dict.getDictKey() + "'失败，会员等级代号已存在");
        }

        return toAjax(systemDictService.updateDict(dict));
    }


    /**
     * 会员等级列表显示接口（填充下拉框）
     */
//    @PreAuthorize("@ss.hasPermi('system:post:query')")
    @GetMapping(value = "/selectOption/{type}")
    public AjaxResult selectOption(@PathVariable Integer type)
    {
        return AjaxResult.success(systemDictService.selectOption(type));
    }

}
