package com.ruoyi.project.hit.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.ruoyi.common.exception.CustomException;
import com.ruoyi.project.hit.domain.CardGame;
import com.ruoyi.project.hit.domain.CardGameProduct;
import com.ruoyi.project.hit.domain.CardGameRule;
import com.ruoyi.project.hit.service.CardGameProductService;
import com.ruoyi.project.hit.mapper.CardGameProductMapper;
import com.ruoyi.project.hit.service.CardGameService;
import com.ruoyi.project.hit.service.CardUserHitService;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.Date;
import java.util.HashMap;
import java.util.List;

/**
* @author HP
* @description 针对表【card_game_product】的数据库操作Service实现
* @createDate 2024-05-28 16:27:44
*/
@Service
public class CardGameProductServiceImpl extends ServiceImpl<CardGameProductMapper, CardGameProduct>
    implements CardGameProductService{

    @Resource
    private CardGameProductMapper cardGameProductMapper;
    @Resource
    private CardUserHitService cardUserHitService;
    @Resource
    private CardGameService cardGameService;

    @Override
    public Long queryByProductId(Integer id) {
        LambdaQueryWrapper<CardGameProduct> wrapper=new LambdaQueryWrapper<>();
        wrapper.eq(CardGameProduct::getProductid,id);
        return cardGameProductMapper.selectCount(wrapper);
    }

    @Override
    public List<HashMap> getGameProductByGameId(Integer id) {
        return cardGameProductMapper.getGameProductByGameId(id);
    }

    /**
     * 通过活动id(gameid)删除对应奖品数据
     * @param gameid
     * @return
     */
    @Override
    public int deleteByGameId(Integer gameid) {
        LambdaQueryWrapper<CardGameProduct> wrapper=new LambdaQueryWrapper<>();
        wrapper.eq(CardGameProduct::getGameid,gameid);
        return cardGameProductMapper.delete(wrapper);
    }

    /**
     * 活动奖品配置
     * @param cardGameProduct
     * @return
     */
    @Override
    public int configGameProduct(CardGameProduct cardGameProduct) {
        return cardGameProductMapper.insert(cardGameProduct);
    }

    @Override
    public int getSumAmountByGameId(Integer gameid) {
        return cardGameProductMapper.getSumAmountByGameId(gameid);
    }

    @Override
    public int deleteGameProduct(Integer id) {
        CardGameProduct cardGameProduct = cardGameProductMapper.selectById(id);
        CardGame cardGame = cardGameService.getCardGameByGameId(cardGameProduct.getGameid());
        //如果活动已开始，则不可删除
        if(cardGame.getStartTime().before(new Date())){
            throw new CustomException("活动已开始，不可执行删除操作");
        }
        //活动已开始时，不允许删除该活动的奖品
        return cardGameProductMapper.deleteById(id);
    }
}




