package com.ruoyi.project.hit.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.ruoyi.common.exception.CustomException;
import com.ruoyi.project.hit.domain.CardGameRule;
import com.ruoyi.project.hit.domain.CardUser;
import com.ruoyi.project.hit.service.CardGameProductService;
import com.ruoyi.project.hit.service.CardGameRuleService;
import com.ruoyi.project.hit.mapper.CardGameRuleMapper;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.List;

/**
* @author HP
* @description 针对表【card_game_rule】的数据库操作Service实现
* @createDate 2024-05-22 22:59:16
*/
@Service
public class CardGameRuleServiceImpl extends ServiceImpl<CardGameRuleMapper, CardGameRule>
    implements CardGameRuleService{

    @Resource
    private CardGameRuleMapper cardGameRuleMapper;
    @Resource
    private CardGameProductService cardGameProductService;


    @Override
    public Long queryByDictKey(Integer dictKey) {
        LambdaQueryWrapper<CardGameRule> wrapper=new LambdaQueryWrapper<>();
        wrapper.eq(CardGameRule::getLevelid,dictKey);
        return cardGameRuleMapper.selectCount(wrapper);
    }

    /**
     * 通过gameid拿到gameRuleList
     * @param id gameid
     * @return
     */
    @Override
    public List<HashMap> getGameRuleListByGameId(Integer id) {
        return cardGameRuleMapper.getGameRuleListByGameId(id);
    }

    @Override
    public int deleteByGameId(Integer gameid) {
        LambdaQueryWrapper<CardGameRule> wrapper=new LambdaQueryWrapper<>();
        wrapper.eq(CardGameRule::getGameid,gameid);
        return cardGameRuleMapper.delete(wrapper);
    }

    @Override
    public int configGameRule(CardGameRule cardGameRule) {
        if(cardGameRule.getEnterCount()<cardGameRule.getHitCount()){
            throw new CustomException("最大抽奖数不能小于最大中奖数，策略配置失败");
        }
        LambdaQueryWrapper<CardGameRule> wrapper=new LambdaQueryWrapper<>();
        wrapper.eq(CardGameRule::getGameid,cardGameRule.getGameid());
        wrapper.eq(CardGameRule::getLevelid,cardGameRule.getLevelid());
        CardGameRule cardGameRule1 = cardGameRuleMapper.selectOne(wrapper);
        if(cardGameRule1!=null){
            throw new CustomException("已为该活动的此会员等级配置奖品，请勿重复配置");
        }
        if(cardGameRuleMapper.getHitCountSumByGameId(cardGameRule.getGameid())+cardGameRule.getHitCount()>cardGameProductService.getSumAmountByGameId(cardGameRule.getGameid())){
            throw new CustomException("配置奖品数量超出所准备的数量，配置失败");
        }


        return cardGameRuleMapper.insert(cardGameRule);
    }

    @Override
    public int getHitCountSumByGameId(Integer gameid) {
        return cardGameRuleMapper.getHitCountSumByGameId(gameid);
    }

    @Override
    public int deleteGameRule(Integer id) {
        return cardGameRuleMapper.deleteById(id);
    }

}




