package com.ruoyi.project.hit.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.ruoyi.common.exception.CustomException;
import com.ruoyi.framework.web.domain.AjaxResult;
import com.ruoyi.project.hit.controller.vo.ListCardGameVo;
import com.ruoyi.project.hit.domain.CardGame;
import com.ruoyi.project.hit.domain.CardGameProduct;
import com.ruoyi.project.hit.service.CardGameProductService;
import com.ruoyi.project.hit.service.CardGameRuleService;
import com.ruoyi.project.hit.service.CardGameService;
import com.ruoyi.project.hit.mapper.CardGameMapper;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
* @author HP
* @description 针对表【card_game】的数据库操作Service实现
* @createDate 2024-05-25 21:09:47
*/
@Slf4j
@Service
public class CardGameServiceImpl extends ServiceImpl<CardGameMapper, CardGame>
    implements CardGameService{

    @Resource
    private CardGameMapper cardGameMapper;
    @Resource
    private CardGameRuleService cardGameRuleService;
    @Resource
    private CardGameProductService cardGameProductService;

    @Override
    public List<HashMap> selectCardGameList(ListCardGameVo listCardGameVo) {
        return cardGameMapper.selectCardGameList(listCardGameVo);
    }

    @Override
    public int addCardGame(CardGame cardGame) {
        LambdaQueryWrapper<CardGame> wrapper=new LambdaQueryWrapper<>();
        wrapper.eq(CardGame::getTitle,cardGame.getTitle());
        CardGame cardGame1 = cardGameMapper.selectOne(wrapper);
        if(null!=cardGame1){
            throw new CustomException("该活动标题已存在,添加失败");
        }
        //活动状态  0:未开始  1:已结束(已加载)
        if(cardGame.getStartTime().after(new Date())){
            cardGame.setStatus(0);
        }else {
            cardGame.setStatus(1);
        }
        return cardGameMapper.insert(cardGame);
    }

    @Override
    public Map<String, Object> getCardGameDataById(Integer id) {
        Map<String,Object> map=new HashMap<>();

        List<HashMap> list1 = cardGameRuleService.getGameRuleListByGameId(id);
        map.put("gameRuleList",list1);
        List<HashMap> list2=cardGameProductService.getGameProductByGameId(id);
        map.put("gameProductList",list2);
        CardGame cardGame = cardGameMapper.selectById(id);
        map.put("cardGame",cardGame);
        return map;
    }

    @Override
    public int updateCardGame(CardGame cardGame) {
        LambdaQueryWrapper<CardGame> wrapper =new LambdaQueryWrapper<>();
        wrapper.eq(CardGame::getTitle,cardGame.getTitle());
        wrapper.ne(CardGame::getId,cardGame.getId());
        CardGame cardGame1 = cardGameMapper.selectOne(wrapper);
        if(cardGame1!=null){
            throw new CustomException("该活动标题已存在，修改失败");
        }
        return cardGameMapper.updateById(cardGame);
    }

    @Override
    public int deleteCardGameById(Integer id) {
        CardGame cardGame = cardGameMapper.selectById(id);
        //如果活动已开始，则不可删除
        if(cardGame.getStartTime().before(new Date())){
            throw new CustomException("活动已开始，不可执行删除操作");
        }
        //删除对应活动奖品配置信息
        cardGameProductService.deleteByGameId(id);
        //删除对应活动配置的活动奖品策略
        cardGameRuleService.deleteByGameId(id);
        return cardGameMapper.deleteById(id);
    }

    @Override
    public Map<String, Object> getCardGameDetailById(Integer id) {
        Map<String,Object> map=new HashMap<>();

        List<HashMap> list1 = cardGameRuleService.getGameRuleListByGameId(id);
        map.put("gameRuleList",list1);
        List<HashMap> list2=cardGameProductService.getGameProductByGameId(id);
        map.put("gameProductList",list2);
        HashMap cardGame = cardGameMapper.getCardGameByGameId(id);
        map.put("cardGame",cardGame);
        return map;
    }

    @Override
    public CardGame getCardGameByGameId(Integer gameid) {
        return cardGameMapper.selectById(gameid);
    }
}




