package com.ruoyi.project.hit.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.mchange.lang.DoubleUtils;
import com.ruoyi.common.exception.CustomException;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.project.hit.controller.vo.ExcelCardProductVo;
import com.ruoyi.project.hit.controller.vo.ListCardProductVo;
import com.ruoyi.project.hit.domain.CardProduct;
import com.ruoyi.project.hit.domain.CardUser;
import com.ruoyi.project.hit.domain.SystemDict;
import com.ruoyi.project.hit.mapper.CardUserMapper;
import com.ruoyi.project.hit.service.CardGameProductService;
import com.ruoyi.project.hit.service.CardProductService;
import com.ruoyi.project.hit.mapper.CardProductMapper;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
* @author HP
* @description 针对表【card_product】的数据库操作Service实现
* @createDate 2024-05-24 20:50:39
*/
@Service
public class CardProductServiceImpl extends ServiceImpl<CardProductMapper, CardProduct>
    implements CardProductService{
    @Resource
    private CardProductMapper cardProductMapper;
    @Resource
    private CardGameProductService cardGameProductService;

    @Override
    public List<CardProduct> selectCardProductList(ListCardProductVo listCardProductVo) {
        LambdaQueryWrapper<CardProduct> wrapper=new LambdaQueryWrapper<>();
        if (StringUtils.isNotEmpty(listCardProductVo.getPname())){
            wrapper.like(CardProduct::getPname,listCardProductVo.getPname());
        }
        if (listCardProductVo.getPriceLow()!=0){
            wrapper.ge(CardProduct::getPrice,listCardProductVo.getPriceLow());
        }
        if (listCardProductVo.getPriceHigh()!=0){
            wrapper.le(CardProduct::getPrice,listCardProductVo.getPriceHigh());
        }
        return cardProductMapper.selectList(wrapper);
    }

    @Override
    public int updateProduct(CardProduct cardProduct) {
        LambdaQueryWrapper<CardProduct> wrapper=new LambdaQueryWrapper<>();
        wrapper.ne(CardProduct::getId,cardProduct.getId());
        wrapper.eq(CardProduct::getPname,cardProduct.getPname());
        CardProduct cardProduct1 = cardProductMapper.selectOne(wrapper);
        if(cardProduct1!=null){
            throw new CustomException("该奖品名已存在,修改失败");
        }
        return cardProductMapper.updateById(cardProduct);
    }

    @Override
    public CardProduct getProductById(Integer id) {
        return cardProductMapper.selectById(id);
    }

    @Override
    public int deleteProduct(Integer id) {
        Long i = cardGameProductService.queryByProductId(id);
        if(i>0){
            throw new CustomException("该奖品已被活动配置，无法删除");
        }
        return cardProductMapper.deleteById(id);
    }

    @Override
    public int addProduct(CardProduct cardProduct) {
        LambdaQueryWrapper<CardProduct> wrapper=new LambdaQueryWrapper<>();
        wrapper.eq(CardProduct::getPname,cardProduct.getPname());
        CardProduct cardProduct1 = cardProductMapper.selectOne(wrapper);
        if(cardProduct1!=null){
            throw new CustomException("该奖品名已存在,添加失败");
        }
        return cardProductMapper.insert(cardProduct);
    }

    @Override
    public List<Map<String,Object>> select() {
        LambdaQueryWrapper<CardProduct> wrapper=new LambdaQueryWrapper<>();
        wrapper.select(CardProduct::getId,CardProduct::getPname);
        return cardProductMapper.selectMaps(wrapper);
    }



}




