package com.ruoyi.project.hit.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.ruoyi.common.constant.UserConstants;
import com.ruoyi.common.exception.CustomException;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.project.hit.domain.SystemDict;
import com.ruoyi.project.hit.mapper.CardUserMapper;
import com.ruoyi.project.hit.service.CardGameRuleService;
import com.ruoyi.project.hit.service.CardUserService;
import com.ruoyi.project.hit.service.SystemDictService;
import com.ruoyi.project.hit.mapper.SystemDictMapper;

import com.ruoyi.project.system.domain.SysPost;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

/**
* @author yifeng868
* @description 针对表【system_dict】的数据库操作Service实现
* @createDate 2024-05-11 15:59:46
*/
@Service
public class SystemDictServiceImpl extends ServiceImpl<SystemDictMapper, SystemDict>
    implements SystemDictService{
    @Resource
    private SystemDictMapper systemDictMapper;
    @Resource
    private CardUserService cardUserService;
    @Resource
    private CardGameRuleService cardGameRuleService;



    @Override
    public List<SystemDict> selectSystemDictList(SystemDict dict) {
        LambdaQueryWrapper<SystemDict> wrapper=new LambdaQueryWrapper<>();
        wrapper.eq(SystemDict::getDictType,dict.getDictType());
        if (StringUtils.isNotEmpty(dict.getDictValue())){
            wrapper.like(SystemDict::getDictValue,dict.getDictValue());
        }
        return systemDictMapper.selectList(wrapper);
    }

    /**
     * 校验会员等级名称是否唯一
     *
     * @param dict 会员等级信息
     * @return 结果
     */
    @Override
    public String checkDictValueUnique(SystemDict dict) {
        //是否传入id的判断
        Long distId = StringUtils.isNull(dict.getId()) ? -1L : dict.getId();
        LambdaQueryWrapper<SystemDict> wrapper=new LambdaQueryWrapper<>();
        wrapper.eq(SystemDict::getDictType,dict.getDictType());
        wrapper.eq(SystemDict::getDictValue,dict.getDictValue());
        SystemDict info = systemDictMapper.selectOne(wrapper);
        if (StringUtils.isNotNull(info) && info.getId().longValue() != distId.longValue())
        {
            return UserConstants.NOT_UNIQUE;
        }
        return UserConstants.UNIQUE;

    }

    /**
     * 校验会员等级编码是否唯一
     *
     * @param dict 会员等级信息
     * @return 结果
     */
    @Override
    public String checkDictKeyUnique(SystemDict dict) {
        Long distId = StringUtils.isNull(dict.getId()) ? -1L : dict.getId();
        LambdaQueryWrapper<SystemDict> wrapper=new LambdaQueryWrapper<>();
        wrapper.eq(SystemDict::getDictType,dict.getDictType());
        wrapper.eq(SystemDict::getDictKey,dict.getDictKey());
        SystemDict info = systemDictMapper.selectOne(wrapper);
        if (StringUtils.isNotNull(info) && info.getId().longValue() != distId.longValue())
        {
            return UserConstants.NOT_UNIQUE;
        }
        return UserConstants.UNIQUE;

    }


    /**
     * 新增保存会员等级信息
     *
     * @param dict 会员等级信息
     * @return 结果
     */
    @Override
    public int insertDict(SystemDict dict) {
        return systemDictMapper.insert(dict);
    }

    /**
     * 删除会员等级信息
     *
     * @param id 会员等级ID
     * @return 结果
     */
    @Override
    public int deleteDictById(Integer id) {
        //根据id查询会员等级编号
        SystemDict systemDict = systemDictMapper.selectById(id);
        Long i=cardUserService.queryByDictKey(systemDict.getDictKey());
        if(i>0){
            throw new CustomException("会员等级编号在其他处调用");
        }
        Long j=cardGameRuleService.queryByDictKey(systemDict.getDictKey());
        if(j>0){
            throw new CustomException("会员等级编号在其他处调用");
        }

        return systemDictMapper.deleteById(id);
    }

    /**
     * 通过会员等级ID查询信息
     *
     * @param  id 会员等级id
     * @return
     */
    @Override
    public SystemDict selectDictById(Long id) {
        return systemDictMapper.selectById(id);
    }

    @Override
    public int updateDict(SystemDict dict) {
        LambdaQueryWrapper<SystemDict> wrapper=new LambdaQueryWrapper<>();
        wrapper.eq(SystemDict::getId,dict.getId());
        return systemDictMapper.update(dict,wrapper);
    }

    @Override
    public List<SystemDict> selectOption(Integer type) {
        String dictType="";
        if(type==1){
            dictType="userlevel";
        }else if(type==2){
            dictType="gametype";
        }
        LambdaQueryWrapper<SystemDict> wrapper=new LambdaQueryWrapper<>();
        wrapper.eq(SystemDict::getDictType,dictType);
        wrapper.select(SystemDict::getDictKey,SystemDict::getDictValue);
        System.out.println(systemDictMapper.selectList(wrapper));
        return systemDictMapper.selectList(wrapper);
    }
}




